@@ -1,6 +1,6 @@
 #! /bin/sh
 #
-# This is a kernel build script for openSUSE 12.2's 3.4 kernel.
+# This is a kernel build script for openSUSE 11.3's 2.6.34 kernel.
 #
 
 die () {
@@ -60,24 +60,24 @@ fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
 
-if [ ! -r kernel-source-3.4.11-2.16.1.src.rpm ]
+if [ ! -r kernel-source-2.6.34.10-0.6.1.src.rpm ]
 then
-    wget http://download.opensuse.org/update/12.2/src/kernel-source-3.4.11-2.16.1.src.rpm || die "Can't download source package."
+    wget http://download.opensuse.org/update/11.3/rpm/src/kernel-source-2.6.34.10-0.6.1.src.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-source-3.4.11-2.16.1.src.rpm || die "Can't verify signature."
-rpm -ivh kernel-source-3.4.11-2.16.1.src.rpm || die "Can't install source package."
+rpm --checksig kernel-source-2.6.34.10-0.6.1.src.rpm || die "Can't verify signature."
+rpm -ivh kernel-source-2.6.34.10-0.6.1.src.rpm || die "Can't install source package."
 
-if [ ! -r kernel-default-3.4.11-2.16.1.nosrc.rpm ]
+if [ ! -r kernel-default-2.6.34.10-0.6.1.nosrc.rpm ]
 then
-    wget http://download.opensuse.org/update/12.2/nosrc/kernel-default-3.4.11-2.16.1.nosrc.rpm || die "Can't download source package."
+    wget http://download.opensuse.org/update/11.3/rpm/src/kernel-default-2.6.34.10-0.6.1.nosrc.rpm || die "Can't download source package."
 fi
-rpm --checksig kernel-default-3.4.11-2.16.1.nosrc.rpm || die "Can't verify signature."
-rpm -ivh kernel-default-3.4.11-2.16.1.nosrc.rpm || die "Can't install source package."
+rpm --checksig kernel-default-2.6.34.10-0.6.1.nosrc.rpm || die "Can't verify signature."
+rpm -ivh kernel-default-2.6.34.10-0.6.1.nosrc.rpm || die "Can't install source package."
 
 cd /usr/src/packages/SOURCES/ || die "Can't chdir to /usr/src/packages/SOURCES/ ."
-if [ ! -r ccs-patch-1.8.3-20121015.tar.gz ]
+if [ ! -r ccs-patch-1.8.3-20121111.tar.gz ]
 then
-    wget -O ccs-patch-1.8.3-20121015.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20121015.tar.gz' || die "Can't download patch."
+    wget -O ccs-patch-1.8.3-20121111.tar.gz 'http://sourceforge.jp/frs/redir.php?f=/tomoyo/49684/ccs-patch-1.8.3-20121111.tar.gz' || die "Can't download patch."
 fi
 
 cd /tmp/ || die "Can't chdir to /tmp/ ."
@@ -85,31 +85,31 @@ cp -p /usr/src/packages/SPECS/kernel-default.spec . || die "Can't copy spec file
 patch << "EOF" || die "Can't patch spec file."
 --- kernel-default.spec
 +++ kernel-default.spec
-@@ -55,10 +55,10 @@
+@@ -53,10 +53,10 @@
  %define install_vdso 0
  %endif
  
 -Name:           kernel-default
 +Name:           ccs-kernel-default
  Summary:        The Standard Kernel
- Version:        3.4.11
--Release:        2.16.1
-+Release:        2.16.1_tomoyo_1.8.3p7
- License:        GPL-2.0
- Group:          System/Kernel
- Url:            http://www.kernel.org/
-@@ -342,6 +342,11 @@
+ Version:        2.6.34.10
+-Release:        0.6.1
++Release:        0.6.1_tomoyo_1.8.3p7
+ %if %using_buildservice
+ %else
+ %endif
+@@ -306,6 +306,11 @@
  %endif
  	%_sourcedir/series.conf .. $SYMBOLS
  
 +# TOMOYO Linux
-+tar -zxf %_sourcedir/ccs-patch-1.8.3-20121015.tar.gz
-+patch -sp1 < patches/ccs-patch-3.4-suse-12.2.diff
++tar -zxf %_sourcedir/ccs-patch-1.8.3-20121111.tar.gz
++patch -sp1 < patches/ccs-patch-2.6.34-suse-11.3.diff
 +cat config.ccs >> ../config/%cpu_arch_flavor
 +
  cd %kernel_build_dir
  
- # Override the timestamp 'uname -v' reports with the source timestamp and
+ if [ -f %_sourcedir/localversion ] ; then
 EOF
 sed -e 's:^Provides:#Provides:' -e 's:^Obsoletes:#Obsoletes:' -e 's:-n kernel:-n ccs-kernel:' kernel-default.spec > ccs-kernel.spec || die "Can't edit spec file."
 echo ""
